<?php
/**
 * Tijarat Business: Customizer
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function tijarat_business_customize_register( $wp_customize ) {

	$wp_customize->add_panel( 'tijarat_business_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'Theme Settings', 'tijarat-business' ),
	    'description' => __( 'Description of what this panel does.', 'tijarat-business' ),
	) );

	// Add the Theme Color Option section.
	$wp_customize->add_section( 'tijarat_business_theme_color_option', 
		array( 'panel' => 'tijarat_business_panel_id', 'title' => esc_html__( 'Theme Color Option', 'tijarat-business' ) )
	);

  	$wp_customize->add_setting( 'tijarat_business_theme_color', array(
	    'default' => '#5467ea',
	    'sanitize_callback' => 'sanitize_hex_color'
  	));
  	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'tijarat_business_theme_color', array(
  		'label' => 'Color Option',
	    'description' => __('One can change complete theme color on just one click.
', 'tijarat-business'),
	    'section' => 'tijarat_business_theme_color_option',
	    'settings' => 'tijarat_business_theme_color',
  	)));

	$wp_customize->add_section( 'tijarat_business_general_option', array(
    	'title'      => __( 'Sidebar Settings', 'tijarat-business' ),
		'priority'   => 30,
		'panel' => 'tijarat_business_panel_id'
	) );

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('tijarat_business_layout_settings',array(
        'default' => __('Right Sidebar','tijarat-business'),
        'sanitize_callback' => 'tijarat_business_sanitize_choices'	        
	));

	$wp_customize->add_control('tijarat_business_layout_settings',array(
        'type' => 'radio',
        'label'     => __('Theme Sidebar Layouts', 'tijarat-business'),
        'description'   => __('This option work for blog page, blog single page, archive page and search page.', 'tijarat-business'),
        'section' => 'tijarat_business_general_option',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','tijarat-business'),
            'Right Sidebar' => __('Right Sidebar','tijarat-business'),
            'One Column' => __('Full Width','tijarat-business'),
            'Grid Layout' => __('Grid Layout','tijarat-business')
        ),
	));

	//home page slider
	$wp_customize->add_section( 'tijarat_business_slider' , array(
    	'title'      => __( 'Slider Settings', 'tijarat-business' ),
		'priority'   => null,
		'panel' => 'tijarat_business_panel_id'
	) );

	$wp_customize->add_setting('tijarat_business_slider_arrows',array(
        'default' => 'true',
        'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('tijarat_business_slider_arrows',array(
     	'type' => 'checkbox',
      	'label' => __('Show / Hide slider','tijarat-business'),
      	'section' => 'tijarat_business_slider',
	));

	for ( $count = 1; $count <= 4; $count++ ) {

		$wp_customize->add_setting( 'tijarat_business_slide_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'tijarat_business_sanitize_dropdown_pages'
		) );

		$wp_customize->add_control( 'tijarat_business_slide_page' . $count, array(
			'label'    => __( 'Select Slide Image Page', 'tijarat-business' ),
			'section'  => 'tijarat_business_slider',
			'type'     => 'dropdown-pages'
		) );
	}

	//About
	$wp_customize->add_section('tijarat_business_about',array(
		'title'	=> __('About','tijarat-business'),
		'description'	=> __('Add About Section below.','tijarat-business'),
		'panel' => 'tijarat_business_panel_id',
	));

	$wp_customize->add_setting( 'tijarat_business_about_page', array(
		'default'           => '',
		'sanitize_callback' => 'tijarat_business_sanitize_dropdown_pages'
	) );
	$wp_customize->add_control( 'tijarat_business_about_page', array(
		'label'    => __( 'Select About Page', 'tijarat-business' ),
		'section'  => 'tijarat_business_about',
		'type'     => 'dropdown-pages'
	) );

	$wp_customize->add_section('tijarat_business_service',array(
		'title'	=> __('Our Services','tijarat-business'),
		'description'	=> __('Add Our Services sections below.','tijarat-business'),
		'panel' => 'tijarat_business_panel_id',
	));

	$wp_customize->add_setting('tijarat_business_service_title',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('tijarat_business_service_title',array(
		'label'	=> __('Section Title','tijarat-business'),
		'section'	=> 'tijarat_business_service',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('tijarat_business_service_text',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('tijarat_business_service_text',array(
		'label'	=> __('Add Text','tijarat-business'),
		'section'	=> 'tijarat_business_service',
		'type'		=> 'text'
	));

	$categories = get_categories();
	$cats = array();
	$i = 0;
	$cat_post[]= 'select';
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_post[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('tijarat_business_service_category',array(
		'default'	=> 'select',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('tijarat_business_service_category',array(
		'type'    => 'select',
		'description'	=> __('Image Size (537 x 358)','tijarat-business'),
		'choices' => $cat_post,
		'label' => __('Select Category to display Latest Post','tijarat-business'),
		'section' => 'tijarat_business_service',
	));

	//Footer
	$wp_customize->add_section( 'tijarat_business_footer' , array(
    	'title'      => __( 'Footer Text', 'tijarat-business' ),
		'priority'   => null,
		'panel' => 'tijarat_business_panel_id'
	) );

	$wp_customize->add_setting('tijarat_business_footer_text',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('tijarat_business_footer_text',array(
		'label'	=> __('Add Copyright Text','tijarat-business'),
		'section'	=> 'tijarat_business_footer',
		'setting'	=> 'tijarat_business_footer_text',
		'type'		=> 'text'
	));


	$wp_customize->get_setting( 'blogname' )->transport          = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport   = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.site-title a',
		'render_callback' => 'tijarat_business_customize_partial_blogname',
	) );
	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => '.site-description',
		'render_callback' => 'tijarat_business_customize_partial_blogdescription',
	) );
	
}
add_action( 'customize_register', 'tijarat_business_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @since Tijarat Business 1.0
 * @see tijarat-business_customize_register()
 *
 * @return void
 */
function tijarat_business_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @since Tijarat Business 1.0
 * @see tijarat-business_customize_register()
 *
 * @return void
 */
function tijarat_business_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Return whether we're on a view that supports a one or two column layout.
 */
function tijarat_business_is_view_with_layout_option() {
	// This option is available on all pages. It's also available on archives when there isn't a sidebar.
	return ( is_page() || ( is_archive() && ! is_active_sidebar( 'footer-1' ) ) );
}

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Tijarat_Business_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'Tijarat_Business_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(
			new Tijarat_Business_Customize_Section_Pro(
				$manager,
				'example_1',
				array(
					'priority' => 9,
					'title'    => esc_html__( 'Tijarat Business Pro', 'tijarat-business' ),
					'pro_text' => esc_html__( 'Go Pro', 'tijarat-business' ),
					'pro_url'  => esc_url('https://www.themeseye.com/wordpress/wordpress-themes-for-business/'),
				)
			)
		);
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'tijarat-business-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'tijarat-business-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
Tijarat_Business_Customize::get_instance();